MediaType

Enum MediaType 

pub enum MediaType {
    Audio = 1,
    Video = 2,
    Both = 3,
}
Media type of the traffic which starts/stops flowing in some Endpoint.

Variants



Audio = 1

Started/stopped audio traffic.



Video = 2

Started/stopped video traffic.



Both = 3

Started/stopped audio and video traffic.

In bitflag representation this variant will be equal to MediaType::Audio + MediaType::Video.

Implementations

Source

impl MediaType

pub fn get_started(self, after: Self) -> Option<Self>

Returns MediaType which was started based on the provided MediaTypes.

This MediaType should be what was before RTCStat update and as argument is MediaType which was got after RTCStat update.