Peer

Struct Peer 

pub struct Peer<S> { /* private fields */ }
RTCPeerConnection representation.

Implementations

Source

impl<T> Peer<T>

pub fn member_id(&self) -> &MemberId

Returns ID of Member associated with this Peer.

pub fn id(&self) -> Id

Returns ID of Peer.

pub fn partner_peer_id(&self) -> Id

Returns ID of interconnected Peer.

pub fn partner_member_id(&self) -> &MemberId

Returns ID of interconnected Member.

pub fn local_sdp(&self) -> Option<&str>

Returns SDP offer of this Peer.

pub fn remote_sdp(&self) -> Option<&str>

Returns SDP offer of the partner Peer.

pub fn get_updates(&self) -> Vec<PeerUpdate>

Returns PeerUpdates of this Peer which should be sent to the client in the Event::PeerUpdated.

pub fn new_tracks(&self) -> Vec<Track>

Returns Tracks that remote Peer is not aware of.

pub fn is_sender(&self) -> bool

Indicates whether this Peer has any send tracks.

pub fn is_force_relayed(&self) -> bool

Indicates whether all media is forcibly relayed through a TURN server.

pub fn ice_servers_list(&self) -> Option<Vec<IceServer>>

Returns vector of IceServers built from this Peers IceUser.

pub fn set_ice_user(&mut self, ice_user: IceUser)

Sets IceUser, which is used to generate IceServers

pub fn endpoints(&self) -> Vec<WeakEndpoint>

Returns WeakEndpoints for which this Peer was created.

pub fn add_endpoint(&mut self, endpoint: &Endpoint)

Adds Endpoint for which this Peer was created.

pub fn receivers(&self) -> &HashMap<TrackId, Rc<MediaTrack>>

Returns all receiving MediaTracks of this Peer.

pub fn senders(&self) -> &HashMap<TrackId, Rc<MediaTrack>>

Returns all sending MediaTracks of this Peer.

pub fn force_commit_partner_changes(&mut self)

Forcibly commits all the PeerChange::PartnerTrackPatches.

pub fn inner_force_commit_scheduled_changes(&mut self)

Commits all PeerChanges which are marked as forcible (PeerChange::can_force_apply).

pub fn is_known_to_remote(&self) -> bool

Indicates whether this Peer is known to client (Event::PeerCreated for this Peer was sent to the client).

pub fn is_empty(&self) -> bool

Returns true if this Peer doesn’t have any Send and Recv MediaTracks.

pub fn as_changes_scheduler(&mut self) -> PeerChangesScheduler<'_>

Returns PeerChangesScheduler for this Peer.

pub fn add_ice_candidate(&mut self, ice_candidate: IceCandidate)

Adds the provided IceCandidate to this Peer.

pub fn ice_candidates(&self) -> &HashSet<IceCandidate>

Returns all IceCandidates received for this Peer.

pub fn is_ice_restart(&self) -> bool

Indicates whether an ICE restart should be performed for this Peer.

pub fn negotiation_role(&self) -> Option<NegotiationRole>

Returns the current NegotiationRole of this Peer.

pub fn set_initialized(&mut self)

Marks this Peer as initialized.

Source

impl Peer<WaitLocalSdp>

pub fn set_local_offer(self, local_sdp: String) -> Peer<WaitRemoteSdp>

Sets local description and transition Peer to WaitRemoteSdp state.

pub fn set_local_answer(self, sdp_answer: String) -> Peer<Stable>

Sets local description and transition Peer to Stable state.

pub fn set_mids( &mut self, mids: HashMap<TrackId, String>, ) -> Result<(), PeerError>

Sets tracks mids.

Provided mids must have entries for all Peers tracks.

Errors

Errors with PeerError::MidsMismatch if Peer is sending MediaTrack without providing its mid.

pub fn update_senders_statuses(&self, senders_statuses: HashMap<TrackId, bool>)

Updates this Peer’s senders statuses.

Source

impl Peer<WaitRemoteSdp>

pub fn set_remote_answer(self, sdp_answer: String) -> Peer<Stable>

Sets remote description and transitions Peer to Stable state.

pub fn set_remote_offer(self, sdp_offer: String) -> Peer<WaitLocalSdp>

Sets remote description and transitions Peer to WaitLocalSdp state.

Source

impl Peer<Stable>

pub fn new( id: Id, member_id: MemberId, partner_peer: Id, partner_member: MemberId, is_force_relayed: bool, peer_updates_sub: Rc<dyn PeerUpdatesSubscriber>, ) -> Self

Creates new Peer for Member.

pub fn start_as_offerer(self) -> Peer<WaitLocalSdp>

Changes Peer state to WaitLocalSdp and discards previously saved SDP Offer and Answer.

Resets Context::local_sdp and Context::remote_sdp.

pub fn start_as_answerer(self) -> Peer<WaitRemoteSdp>

Changes Peer state to WaitLocalSdp and discards previously saved SDP Offer and Answer.

Resets Context::local_sdp and Context::remote_sdp.

pub fn get_mids(&self) -> Result<HashMap<TrackId, String>, PeerError>

Returns mids of this Peer.

Errors

Errors with PeerError::MidsMismatch if Peer is sending MediaTrack without providing its mid.