pub struct Rpc {
pub idle_timeout: Duration,
pub reconnect_timeout: Duration,
pub ping_interval: Duration,
}Expand description
RPC connection settings.
Fields
idle_timeout: DurationDuration, after which remote RPC client will be considered idle if no heartbeat messages received.
It applies to all related pipelines as default value, but can be overridden for each specific case via Control API.
Defaults to 10s.
reconnect_timeout: DurationDuration, after which the server deletes the client session if the remote RPC client does not reconnect after it is idle.
It applies to all related pipelines as default value, but can be overridden for each specific case via Control API.
Defaults to 10s.
ping_interval: DurationInterval of sending Pings from the server to the client.
It applies to all related pipelines as default value, but can be overridden for each specific case via Control API.
Defaults to 3s.